@@ -4,7 +4,7 @@
 
 static struct feed_entry **feeds = NULL;
 static size_t feeds_count = 0;
-static int feeds_sort = SORT_BY_ORIGINAL_ASC;
+static sorting_method_t feeds_sort = SORT_BY_INITIAL_ASC;
 static struct feed_entry **feeds_original = NULL;
 
 static bool
@@ -26,14 +26,20 @@ get_feed_args(struct menu_state *ctx, size_t index)
 	feed_fmt[0].value.i = index + 1;
 	feed_fmt[1].value.i = ctx->feeds[index]->unread_count;
 	feed_fmt[2].value.s = ctx->feeds[index]->link->ptr;
-	feed_fmt[3].value.s = ctx->feeds[index]->name->ptr;
+	feed_fmt[3].value.s = STRING_IS_EMPTY(ctx->feeds[index]->name) ? ctx->feeds[index]->link->ptr : ctx->feeds[index]->name->ptr;
 	return feed_fmt;
 }
 
 static unsigned
 paint_feed(struct menu_state *ctx, size_t index)
 {
-	return get_cfg_color(&ctx->feeds[index]->cfg, ctx->feeds[index]->unread_count > 0 ? CFG_COLOR_LIST_FEED_UNREAD : CFG_COLOR_LIST_FEED);
+	if (ctx->feeds[index]->has_errors && !get_cfg_bool(&ctx->feeds[index]->cfg, CFG_SUPPRESS_ERRORS)) {
+		return get_cfg_color(&ctx->feeds[index]->cfg, CFG_COLOR_LIST_FEED_FAILED);
+	} else if (ctx->feeds[index]->unread_count > 0) {
+		return get_cfg_color(&ctx->feeds[index]->cfg, CFG_COLOR_LIST_FEED_UNREAD);
+	} else {
+		return get_cfg_color(&ctx->feeds[index]->cfg, CFG_COLOR_LIST_FEED);
+	}
 }
 
 static bool
@@ -43,7 +49,7 @@ is_feed_unread(struct menu_state *ctx, size_t index)
 }
 
 static int
-compare_feeds_original(const void *data1, const void *data2)
+compare_feeds_initial(const void *data1, const void *data2)
 {
 	struct feed_entry *feed1 = *(struct feed_entry **)data1;
 	struct feed_entry *feed2 = *(struct feed_entry **)data2;
@@ -64,7 +70,7 @@ compare_feeds_unread(const void *data1, const void *data2)
 	struct feed_entry *feed2 = *(struct feed_entry **)data2;
 	if (feed1->unread_count > feed2->unread_count) return feeds_sort & 1 ? -1 : 1;
 	if (feed1->unread_count < feed2->unread_count) return feeds_sort & 1 ? 1 : -1;
-	return compare_feeds_original(data1, data2) * (feeds_sort & 1 ? -1 : 1);
+	return compare_feeds_initial(data1, data2) * (feeds_sort & 1 ? -1 : 1);
 }
 
 static int
@@ -72,20 +78,22 @@ compare_feeds_alphabet(const void *data1, const void *data2)
 {
 	struct feed_entry *feed1 = *(struct feed_entry **)data1;
 	struct feed_entry *feed2 = *(struct feed_entry **)data2;
-	return strcmp(feed1->name->ptr, feed2->name->ptr) * (feeds_sort & 1 ? -1 : 1);
+	const char *token1 = STRING_IS_EMPTY(feed1->name) ? feed1->link->ptr : feed1->name->ptr;
+	const char *token2 = STRING_IS_EMPTY(feed2->name) ? feed2->link->ptr : feed2->name->ptr;
+	return strcmp(token1, token2) * (feeds_sort & 1 ? -1 : 1);
 }
 
 static inline void
-sort_feeds(struct menu_state *m, int sorting_method, bool we_are_already_in_feeds_menu)
+sort_feeds(struct menu_state *m, sorting_method_t method, bool we_are_already_in_feeds_menu)
 {
+	pthread_mutex_lock(&interface_lock);
 	feeds          = m->feeds;
 	feeds_count    = m->feeds_count;
 	feeds_original = m->feeds_original;
-	feeds_sort     = sorting_method;
-	pthread_mutex_lock(&interface_lock);
+	feeds_sort     = method;
 	switch (feeds_sort & ~1) {
-		case SORT_BY_ORIGINAL_ASC: qsort(feeds, feeds_count, sizeof(struct feed_entry *), &compare_feeds_original); break;
 		case SORT_BY_UNREAD_ASC:   qsort(feeds, feeds_count, sizeof(struct feed_entry *), &compare_feeds_unread);   break;
+		case SORT_BY_INITIAL_ASC:  qsort(feeds, feeds_count, sizeof(struct feed_entry *), &compare_feeds_initial);  break;
 		case SORT_BY_ALPHABET_ASC: qsort(feeds, feeds_count, sizeof(struct feed_entry *), &compare_feeds_alphabet); break;
 	}
 	pthread_mutex_unlock(&interface_lock);
@@ -136,7 +144,7 @@ feeds_menu_loop(struct menu_state *m)
 			case INPUT_RELOAD_ALL:      queue_updates(m->feeds_original, m->feeds_count);  break;
 			case INPUT_QUIT_HARD:       return NULL;
 			case INPUT_ENTER:
-				return setup_menu(&items_menu_loop, m->feeds[m->view_sel]->name, m->feeds + m->view_sel, 1, MENU_NORMAL);
+				return setup_menu(&items_menu_loop, NULL, m->feeds + m->view_sel, 1, MENU_NORMAL);
 			case INPUT_TOGGLE_EXPLORE_MODE:
 				return setup_menu(&items_menu_loop, NULL, m->feeds, m->feeds_count, MENU_IS_EXPLORE);
 			case INPUT_APPLY_SEARCH_MODE_FILTER:
@@ -149,11 +157,14 @@ feeds_menu_loop(struct menu_state *m)
 			case INPUT_SORT_BY_UNREAD:
 				sort_feeds(m, feeds_sort == SORT_BY_UNREAD_DESC ? SORT_BY_UNREAD_ASC : SORT_BY_UNREAD_DESC, true);
 				break;
+			case INPUT_SORT_BY_INITIAL:
+				sort_feeds(m, feeds_sort == SORT_BY_INITIAL_ASC ? SORT_BY_INITIAL_DESC : SORT_BY_INITIAL_ASC, true);
+				break;
 			case INPUT_SORT_BY_ALPHABET:
 				sort_feeds(m, feeds_sort == SORT_BY_ALPHABET_ASC ? SORT_BY_ALPHABET_DESC : SORT_BY_ALPHABET_ASC, true);
 				break;
-			case INPUT_STATUS_HISTORY_MENU:
-				return setup_menu(&status_pager_loop, NULL, NULL, 0, MENU_NORMAL);
+			case INPUT_VIEW_ERRORS:
+				return setup_menu(&errors_pager_loop, NULL, m->feeds + m->view_sel, 1, MENU_NORMAL);
 		}
 	}
 	return NULL;
