@@ -21,7 +21,9 @@ static struct input_entry inputs[] = {
 INPUT(INPUT_SELECT_NEXT,              {"j", "KEY_DOWN", "^E"},                  {"select-next"})
 INPUT(INPUT_SELECT_PREV,              {"k", "KEY_UP", "^Y"},                    {"select-prev"})
 INPUT(INPUT_SELECT_NEXT_PAGE,         {"space", "^F", "KEY_NPAGE"},             {"select-next-page"})
-INPUT(INPUT_SELECT_PREV_PAGE,         {"^B", "KEY_PPAGE", },                    {"select-prev-page"})
+INPUT(INPUT_SELECT_NEXT_PAGE_HALF,    {"^D"},                                   {"select-next-page-half"})
+INPUT(INPUT_SELECT_PREV_PAGE,         {"^B", "KEY_PPAGE"},                      {"select-prev-page"})
+INPUT(INPUT_SELECT_PREV_PAGE_HALF,    {"^U"},                                   {"select-prev-page-half"})
 INPUT(INPUT_SELECT_FIRST,             {"g", "KEY_HOME"},                        {"select-first"})
 INPUT(INPUT_SELECT_LAST,              {"G", "KEY_END"},                         {"select-last"})
 INPUT(INPUT_JUMP_TO_NEXT,             {"J"},                                    {"jump-to-next"})
@@ -37,6 +39,7 @@ INPUT(INPUT_SHIFT_RESET,              {"<"},
 INPUT(INPUT_SORT_BY_TIME,             {"t"},                                    {"sort-by-time"})
 INPUT(INPUT_SORT_BY_ROWID,            {"w"},                                    {"sort-by-rowid"})
 INPUT(INPUT_SORT_BY_UNREAD,           {"u"},                                    {"sort-by-unread"})
+INPUT(INPUT_SORT_BY_INITIAL,          {"z"},                                    {"sort-by-initial"})
 INPUT(INPUT_SORT_BY_ALPHABET,         {"a"},                                    {"sort-by-alphabet"})
 INPUT(INPUT_SORT_BY_IMPORTANT,        {"i"},                                    {"sort-by-important"})
 INPUT(INPUT_ENTER,                    {"l", "enter", "KEY_RIGHT", "KEY_ENTER"}, {"enter"})
@@ -44,12 +47,12 @@ INPUT(INPUT_RELOAD,                   {"r"},
 INPUT(INPUT_RELOAD_ALL,               {"R", "^R"},                              {"reload-all"})
 INPUT(INPUT_MARK_READ,                {}, /* look at assign_default_binds() */  {"read",        "mark-read"})
 INPUT(INPUT_MARK_UNREAD,              {}, /* look at assign_default_binds() */  {"unread",      "mark-unread"})
-INPUT(INPUT_MARK_READ_ALL,            {"^D"},                                   {"read-all",    "mark-read-all"})
+INPUT(INPUT_MARK_READ_ALL,            {"A"},                                    {"read-all",    "mark-read-all"})
 INPUT(INPUT_MARK_UNREAD_ALL,          {}, /* basically unset */                 {"unread-all",  "mark-unread-all"})
 INPUT(INPUT_MARK_IMPORTANT,           {"f"},                                    {"important",   "mark-important"})
 INPUT(INPUT_MARK_UNIMPORTANT,         {"F"},                                    {"unimportant", "mark-unimportant"})
 INPUT(INPUT_TOGGLE_EXPLORE_MODE,      {"tab", "e"},                             {"explore",     "toggle-explore-mode"})
-INPUT(INPUT_STATUS_HISTORY_MENU,      {"v"},                                    {"status-history-menu"})
+INPUT(INPUT_VIEW_ERRORS,              {"v"},                                    {"view-errors"})
 INPUT(INPUT_OPEN_IN_BROWSER,          {"o"},                                    {"open-in-browser"})
 INPUT(INPUT_COPY_TO_CLIPBOARD,        {"y", "c"},                               {"copy-to-clipboard"})
 INPUT(INPUT_START_SEARCH_INPUT,       {"/"},                                    {"start-search-input"})
