@@ -69,7 +69,7 @@ db_insert_item(struct feed_entry *feed, struct getfeed_item *item, int64_t rowid
 	db_bind_string(s,     1 + ITEM_COLUMN_FEED_URL,         feed->link);
 	db_bind_string(s,     1 + ITEM_COLUMN_GUID,             item->guid);
 	db_bind_string(s,     1 + ITEM_COLUMN_TITLE,            item->title);
-	db_bind_string(s,     1 + ITEM_COLUMN_LINK,             (item->url == NULL || item->url->len == 0) && item->guid_is_url == true ? item->guid : item->url);
+	db_bind_string(s,     1 + ITEM_COLUMN_LINK,             STRING_IS_EMPTY(item->url) && item->guid_is_url == true ? item->guid : item->url);
 	db_bind_string(s,     1 + ITEM_COLUMN_CONTENT,          item->content);
 	db_bind_string(s,     1 + ITEM_COLUMN_ATTACHMENTS,      item->attachments);
 	db_bind_string(s,     1 + ITEM_COLUMN_PERSONS,          item->persons);
@@ -99,7 +99,7 @@ bool
 insert_item_data(struct feed_entry *feed, struct getfeed_item *item)
 {
 	// Create guid if it was not set.
-	if ((item->guid == NULL) || (item->guid->len == 0)) {
+	if (STRING_IS_EMPTY(item->guid)) {
 		if ((item->url != NULL) && (item->url->len != 0)) {
 			if (cpyss(&item->guid, item->url) == false) {
 				return false;
