@@ -8,6 +8,8 @@ append_sorting_order_expression_to_query(struct string *q, int order)
 	switch (order) {
 		case SORT_BY_TIME_ASC:       return catas(q, " ORDER BY MAX(publication_date, update_date) ASC, rowid ASC", 59);
 		case SORT_BY_TIME_DESC:      return catas(q, " ORDER BY MAX(publication_date, update_date) DESC, rowid DESC", 61);
+		case SORT_BY_ROWID_ASC:      return catas(q, " ORDER BY rowid ASC", 19);
+		case SORT_BY_ROWID_DESC:     return catas(q, " ORDER BY rowid DESC", 20);
 		case SORT_BY_UNREAD_ASC:     return catas(q, " ORDER BY unread ASC, MAX(publication_date, update_date) DESC, rowid DESC", 73);
 		case SORT_BY_UNREAD_DESC:    return catas(q, " ORDER BY unread DESC, MAX(publication_date, update_date) DESC, rowid DESC", 74);
 		case SORT_BY_IMPORTANT_ASC:  return catas(q, " ORDER BY important ASC, MAX(publication_date, update_date) DESC, rowid DESC", 76);
@@ -22,20 +24,29 @@ append_sorting_order_expression_to_query(struct string *q, int order)
 static inline struct string *
 generate_search_query_string(const struct items_list *items, const struct string *search_filter)
 {
-	struct string *q = crtas("SELECT rowid,feed_url,title,link,publication_date,update_date,unread,important FROM items WHERE feed_url IN (?", 110);
+	struct string *q = crtas("SELECT rowid,feed_url,title,link,publication_date,update_date,unread,important FROM items WHERE (", 97);
 	if (q == NULL) {
 		goto error;
 	}
-	for (size_t i = 1; i < items->feeds_count; ++i) {
-		if (catas(q, ",?", 2) == false) {
+	for (size_t i = 0; i < items->feeds_count; ++i) {
+		if (i > 0 && !catas(q, " OR ", 4)) {
 			goto error;
 		}
+		if (!catas(q, "feed_url=?", 10)) {
+			goto error;
+		}
+		const struct string *item_rule = get_cfg_string(&items->feeds[i]->cfg, CFG_ITEM_RULE);
+		if (item_rule != NULL && item_rule->len > 0) {
+			if (!catas(q, " AND (", 6) || !catss(q, item_rule) || !catcs(q, ')')) {
+				goto error;
+			}
+		}
 	}
-	if (catcs(q, ')') == false) {
+	if (!catcs(q, ')')) {
 		goto error;
 	}
 	if (search_filter != NULL && search_filter->len > 0) {
-		if (catas(q, " AND ((title LIKE '%' || ? || '%') OR (content LIKE '%' || ? || '%'))", 69) == false) {
+		if (!catas(q, " AND ((title LIKE '%' || ? || '%') OR (content LIKE '%' || ? || '%'))", 69)) {
 			goto error;
 		}
 	}
@@ -167,7 +178,7 @@ create_items_list(struct feed_entry **feeds, size_t feeds_count, int sorting, co
 	}
 	items->res = db_prepare(items->query->ptr, items->query->len + 1);
 	if (items->res == NULL) {
-		fail_status("Can't prepare search query for action!");
+		fail_status("Can't run items search query! Make sure the item-rule setting is set correctly.");
 		goto undo2;
 	}
 	for (size_t i = 0; i < feeds_count; ++i) {
@@ -221,6 +232,9 @@ change_items_list_sorting(struct items_list **items, input_id cmd)
 		case INPUT_SORT_BY_TIME:
 			(*items)->sorting = (*items)->sorting == SORT_BY_TIME_DESC ? SORT_BY_TIME_ASC : SORT_BY_TIME_DESC;
 			break;
+		case INPUT_SORT_BY_ROWID:
+			(*items)->sorting = (*items)->sorting == SORT_BY_ROWID_DESC ? SORT_BY_ROWID_ASC : SORT_BY_ROWID_DESC;
+			break;
 		case INPUT_SORT_BY_UNREAD:
 			(*items)->sorting = (*items)->sorting == SORT_BY_UNREAD_DESC ? SORT_BY_UNREAD_ASC : SORT_BY_UNREAD_DESC;
 			break;
