@@ -138,11 +138,11 @@ items_menu_loop(struct menu_state *m)
 	start_menu();
 	const struct wstring *macro, *browser;
 	while (true) {
-		if (m->items_age != items_age) {
+		if (get_cfg_bool(NULL, CFG_MENU_RESPONSIVENESS) && m->items_age != items_age) {
 			m->items_age = items_age;
 			recreate_items_list(&m->items);
 		}
-		if (get_cfg_bool(NULL, CFG_MARK_ITEM_READ_ON_HOVER) == true) {
+		if (get_cfg_bool(&m->items->ptr[m->view_sel].feed[0]->cfg, CFG_MARK_ITEM_READ_ON_HOVER)) {
 			mark_item_read(m, m->view_sel, true);
 		}
 		input_id cmd = get_input(m->items->ptr[m->view_sel].feed[0]->binds, NULL, &macro);
@@ -171,7 +171,7 @@ items_menu_loop(struct menu_state *m)
 				break;
 			case INPUT_GOTO_FEED:
 				if (!(m->flags & MENU_IS_EXPLORE)) break;
-				return setup_menu(&items_menu_loop, m->items->ptr[m->view_sel].feed[0]->name, m->items->ptr[m->view_sel].feed, 1, MENU_NORMAL);
+				return setup_menu(&items_menu_loop, NULL, m->items->ptr[m->view_sel].feed, 1, MENU_NORMAL);
 			case INPUT_APPLY_SEARCH_MODE_FILTER:
 				change_search_filter_of_items_list(&m->items, search_mode_text_input); break;
 			case INPUT_OPEN_IN_BROWSER:
@@ -186,8 +186,6 @@ items_menu_loop(struct menu_state *m)
 				change_items_list_sorting(&m->items, cmd); break;
 			case INPUT_ENTER:
 				return setup_menu(&item_pager_loop, m->items->ptr[m->view_sel].title, NULL, 0, MENU_NORMAL);
-			case INPUT_STATUS_HISTORY_MENU:
-				return setup_menu(&status_pager_loop, NULL, NULL, 0, MENU_NORMAL);
 		}
 	}
 	return close_menu();
