@@ -14,7 +14,7 @@
 #include <yajl/yajl_parse.h>
 
 #ifndef NEWSRAFT_VERSION
-#define NEWSRAFT_VERSION "0.28"
+#define NEWSRAFT_VERSION "0.29"
 #endif
 
 #define ISWHITESPACE(A) (((A)==' ')||((A)=='\n')||((A)=='\t')||((A)=='\v')||((A)=='\f')||((A)=='\r'))
@@ -29,6 +29,7 @@
 #define LENGTH(A) ((sizeof(A))/(sizeof(*A)))
 #define NEWSRAFT_MIN(A, B) (((A) < (B)) ? (A) : (B)) // Need prefix because some platforms have their own MIN definition
 #define NEWSRAFT_CURSES(CALL) do { if (curses_is_running()) { CALL; } } while (0) // Make CALL only if Curses is running
+#define STRING_IS_EMPTY(A) (((A) == NULL) || ((A)->ptr == NULL) || ((A)->len == 0))
 
 typedef uint8_t config_entry_id;
 typedef uint8_t input_id;
@@ -83,9 +84,10 @@ enum {
 	MENU_DISABLE_SETTINGS = 8,
 };
 
+typedef uint8_t sorting_method_t;
 enum { // Even is ascending, odd is descending
-	SORT_BY_ORIGINAL_ASC = 0,
-	SORT_BY_ORIGINAL_DESC,
+	SORT_BY_INITIAL_ASC = 0,
+	SORT_BY_INITIAL_DESC,
 	SORT_BY_TIME_ASC,
 	SORT_BY_TIME_DESC,
 	SORT_BY_ROWID_ASC,
@@ -159,6 +161,8 @@ struct feed_entry {
 	int64_t update_date; // Date of last feed update attempt
 	struct config_context *cfg;
 	struct input_binding *binds;
+	bool has_errors;
+	struct string *errors;
 };
 
 struct item_entry {
@@ -317,7 +321,7 @@ struct feed_update_state {
 // See "sections.c" file for implementation.
 int64_t make_sure_section_exists(const struct string *section_name);
 struct feed_entry *copy_feed_to_section(const struct feed_entry *feed_data, int64_t section_index);
-void refresh_unread_items_count_of_all_sections(void);
+void refresh_sections_statistics_about_underlying_feeds(void);
 bool purge_abandoned_feeds(void);
 struct menu_state *sections_menu_loop(struct menu_state *m);
 void free_sections(void);
@@ -348,7 +352,7 @@ bool handle_list_menu_control(struct menu_state *m, input_id cmd, const struct w
 bool handle_pager_menu_control(input_id cmd);
 void free_menus(void);
 size_t get_menu_depth(void);
-struct menu_state *setup_menu(struct menu_state *(*run)(struct menu_state *), struct string *name, struct feed_entry **feeds, size_t feeds_count, uint32_t flags);
+struct menu_state *setup_menu(struct menu_state *(*run)(struct menu_state *), const struct string *name, struct feed_entry **feeds, size_t feeds_count, uint32_t flags);
 struct menu_state *close_menu(void);
 void start_menu(void);
 void write_menu_path_string(struct string *names, struct menu_state *m);
@@ -468,13 +472,12 @@ void status_clean(void);
 void prevent_status_cleaning(void);
 void allow_status_cleaning(void);
 void status_write(config_entry_id color, const char *format, ...);
-struct string *generate_string_with_status_messages_for_pager(void);
 void status_delete(void);
 input_id get_input(struct input_binding *ctx, uint32_t *count, const struct wstring **macro_ptr);
 void break_getting_input_command(void);
 
-// See "interface-status-pager.c" file for implementation.
-struct menu_state *status_pager_loop(struct menu_state *dest);
+// See "interface-errors-pager.c" file for implementation.
+struct menu_state *errors_pager_loop(struct menu_state *m);
 
 // Functions responsible for managing of key bindings.
 // See "binds.c" file for implementation.
@@ -502,7 +505,8 @@ bool catas(struct string *dest, const char *src_ptr, size_t src_len);
 bool catss(struct string *dest, const struct string *src);
 bool catcs(struct string *dest, char c);
 bool make_string_fit_more(struct string **dest, size_t n);
-bool string_vprintf(struct string *dest, const char *format, va_list args);
+void str_vappendf(struct string *dest, const char *fmt, va_list args);
+void str_appendf(struct string *dest, const char *fmt, ...);
 void empty_string(struct string *dest);
 void free_string(struct string *str);
 void trim_whitespace_from_string(struct string *str);
